#ifndef __ERRCODE_H__
#define __ERRCODE_H__

/*****************************************************************
|----------------------------------------------------------------|
| 1 |   APP_ID   |   MOD_ID    |             ERR_ID              |
|----------------------------------------------------------------|
|<--><--7bits----><----8bits---><------------16bits------------->|
*****************************************************************/

#define SL_ERRCODE_DEFINE(appid, module, errid) \
    ((uint32_t)( (1 << 31) | ((appid) << 24) | ((module) << 16 ) | (errid) ))

#define SL_APPID_MAX                            0x7F
#define SL_MODID_MAX                            0xFF
#define SL_ERRID_MAX                            0xFFFF

#define SL_APPID_SYSTEM                         0x01
#define SL_APPID_CAMERA                         0x02

#define SL_MODID_BASE                           0x01
#define SL_MODID_FACEDB                         0x02
#define SL_MODID_CVENGINE                       0x03
#define SL_MODID_WEBAPI                         0x04

/************************************************************************/
/* 公共错误码                                                           */
/************************************************************************/
#define SL_ERROR_UNKNOWN                        (-1)  /** 未知错误                 */
#define SL_ERROR_NOTFOUND                       (-2)  /** 找不到目标               */
#define SL_ERROR_ILLEGAL_PARAM                  (-3)  /** 无效参数                 */
#define SL_ERROR_NOMEM                          (-4)  /** 内存不足                 */
#define SL_ERROR_NOBUF                          (-5)  /** 没有更多缓冲区           */
#define SL_ERROR_BUF_FULL                       (-6)  /** 缓冲队列已满             */
#define SL_ERROR_BUF_EMPTY                      (-7)  /** 缓冲队列为空             */
#define SL_ERROR_NOPERM                         (-8)  /** 没有权限                 */
#define SL_ERROR_NOT_SUPPORT                    (-9)  /** 操作不支持               */
#define SL_ERROR_BUSY                           (-10) /** 资源繁忙                 */
#define SL_ERROR_NOTREADY                       (-11) /** 未准备就绪               */
#define SL_ERROR_TIMEDOUT                       (-12) /** 操作超时                 */
#define SL_ERROR_DNS                            (-13) /** 网络名称解析失败         */
#define SL_ERROR_CONNECT                        (-14) /** 网络连接失败             */

/************************************************************************/
/* WEBAPI错误码                                                         */
/************************************************************************/
#define SL_ERROR_WEBAPI_LOGIN_FAILED            (0x81040001) /** 登陆失败         */
#define SL_ERROR_WEBAPI_BAD_MESSAGE             (0x81040002) /** 无效消息内容     */

/************************************************************************/
/* 人脸库错误码                                                         */
/************************************************************************/
#define SL_ERROR_FACE_PIXEL_TOO_SMALL           (0x82020001) /** 人脸太小         */
#define SL_ERROR_FACE_PIXEL_TOO_LARGE           (0x82020002) /** 人脸图宽高太大   */
#define SL_ERROR_FACE_PIXEL_ALIGN               (0x82020003) /** 人脸图像素未对齐 */
#define SL_ERROR_FACE_SIZE_TOO_BIG              (0x82020004) /** 人脸图文件太大   */
#define SL_ERROR_FACE_QUALITY                   (0x82020005) /** 人脸质量不合格   */
#define SL_ERROR_FACE_PITCH                     (0x82020006) /** 人脸俯仰角太大   */
#define SL_ERROR_FACE_YAW                       (0x82020007) /** 人脸偏转角太大   */
#define SL_ERROR_FACE_ROLL                      (0x82020008) /** 人脸旋转角太大   */
#define SL_ERROR_FACE_BLUR                      (0x82020009) /** 人脸太模糊       */
#define SL_ERROR_FACE_NOT_DETECTED              (0x8202000A) /** 未检测出人脸     */
#define SL_ERROR_FACE_MULTIPLE                  (0x8202000B) /** 检测出多个人脸   */
#define SL_ERROR_FACE_MODEL                     (0x8202000C) /** 未打开识别功能   */
#define SL_ERROR_FACE_DB_OPEN                   (0x8202000D) /** 脸库打开失败     */
#define SL_ERROR_FACE_DB_INIT                   (0x8202000E) /** 脸库初始化       */
#define SL_ERROR_FACE_DB_PREPARE                (0x8202000F) /** 脸库读取失败     */
#define SL_ERROR_FACE_DB_READ                   (0x82020010) /** 脸库读取失败     */
#define SL_ERROR_FACE_DB_WRITE                  (0x82020011) /** 脸库写入失败     */

#endif // __ERRCODE_H__
